/* Written by Morgoth DBMA, morgothdbma@o2.pl
 This is part of PgXexplorer software, Open Source
 on BSD licence, Libraries(interaces) used:
 GNU GCC, AS (all stuff needed to compile C source into executable binary)
 LibPQ-FE from PostgreSQL, GTK (GIMP Toolkit)
 written in VIM editor, ctags used, CVS used
 Currently only one author: MOrgoth DBMA
 ! THIS FILE IS BASED ON GTK EXAMPLE FROM INTERNET !
 ! MANY GTK UI FUNCTIONS ARE BASED ON SOMEBODY'S EXAMLE CODE !
 ! BUT I DON'T KNOW THEIR PERSONALITY SO SORRY !
 ! I CANNOT ADD THEM TO AUTORS, BUT THANKS FOR SUPPORT ME !
 FILE: toolbar.h */
#ifndef __MORGOTHDBMA_WIZARDS_H__
#define __MORGOTHDBMA_WIZARDS_H__
#include "main.h"

#define DEL_TYPE_EXACTLY	0
#define DEL_TYPE_BEGINS		1
#define DEL_TYPE_ENDS		2
#define DEL_TYPE_CONTAINS	3
#define DEL_TYPE_NONE   	4

#define MAX_TABLE_NAME	     2048

struct PassInsertData
{
 char* tabname;
 int n;
 char** names;
 char** values;
 int*   types;
};

struct WizData
{
 GtkWidget* label;
 GtkWidget* label2;
 GtkWidget* scale;
 GtkWidget* table;
 int ncols;
};

char* insert_wizard(char* tabname);
char* delete_wizard(char* tabname);
char* select_table_wizard(int all_opt);
char* select_view_wizard();
char* ctable_wizard();

#endif
